@@ -6,7 +6,7 @@ qbit::File - Functions to manipulate files.
 =cut
 
 package qbit::File;
-$qbit::File::VERSION = '2.6';
+$qbit::File::VERSION = '2.7';
 use strict;
 use warnings;
 use utf8;
@@ -67,7 +67,7 @@ sub readfile($;%) {
         throw Exception gettext('Cannot open file "%s": %s', $filename, fix_utf($!));
     }
 
-    $opts{'binary'} ? binmode $fh : binmode $fh, ':utf8';
+    binmode $fh;
 
     my $size_left = -s $filename;
 
@@ -85,6 +85,8 @@ sub readfile($;%) {
         last if $size_left <= 0;
     }
 
+    utf8::decode($content) unless $opts{'binary'};
+
     return $content;
 }
 
